Learn R Programming

contactsurveys (version 0.1.0)

contactsurveys-package: contactsurveys: Download Contact Surveys for Use in Infectious Disease Modelling

Description

Download, cache, and manage social contact survey data from the social contact data community on Zenodo (https://zenodo.org/communities/social_contact_data) for use in infectious disease modelling. Provides functions to list available surveys, download survey files with automatic caching, and retrieve citations. Contact survey data describe who contacts whom in a population and are used to parameterise age-structured transmission models, for example via the 'socialmixr' package. The surveys available include those from the POLYMOD study (Mossong et al. (2008) tools:::Rd_expr_doi("10.1371/journal.pmed.0050074")) and other social contact data shared on Zenodo.

Arguments

Author

Maintainer: Sebastian Funk sebastian.funk@lshtm.ac.uk (ORCID) [copyright holder]

Authors:

Other contributors:

  • Hugo Gruson (ORCID) [contributor]

See Also