- survey
A DOI of a survey, (see list_surveys()). If a HTML link is
given, the DOI will be isolated and used.
- directory
Directory of where to save survey files. Defaults to
tempdir(), so files do not persist across R sessions. For persistent
caching, pass contactsurveys_dir(), which uses tools::R_user_dir()
and appends the survey URL/DOI basename as a subdirectory. E.g., if you
provide "10.5281/zenodo.1095664" in the survey argument, it will save
the surveys into a directory zenodo.1095664 under
contactsurveys_dir(). You can also set an environment variable,
CONTACTSURVEYS_HOME, see Sys.setenv() or Renviron for more detail.
- verbose
Whether downloads should be echoed to output. Default TRUE.
- overwrite
If files should be overwritten if they already exist.
Default FALSE
- timeout
A numeric value specifying timeout in seconds. Default
3600 seconds.
- rate
a
purrr rate
object, to facilitate downloading if the download fails. Defaults to an
exponential backoff of 5 seconds (up to 4 attempts: 1 initial + 3 retries)
changed by specifying your own rate object, see ?purrr::rate_backoff()
for details.